.. nodoctest

Coding of Polyhedron exchange transformations (PETs)
====================================================

.. automodule:: slabbe.coding_of_PETs
   :members:
   :undoc-members:
   :show-inheritance:
   

